@@ -1,8 +1,8 @@
-"""Top-level package for pydantic-i18n."""
+"""pydantic-i18n is an extension to support an i18n for the pydantic error messages."""
 
 __author__ = """Roman Sadzhenytsia"""
 __email__ = "urchin.dukkee@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 from .loaders import BabelLoader, BaseLoader, DictLoader, JsonLoader
 from .main import PydanticI18n
